==> react-app-logic-12.1.0.tgz: package/src/exchange/TheGraph/useOnexDayTradeFrame.ts <==
/* eslint-disable class-methods-use-this */
import BigNumber from 'bignumber.js';
import { useCallback } from 'react';
import { AsyncStatus, useAsyncStatuses, useSubscribedValue } from '@onomy/react-utils';
import { DetailedFungibleAssetBalance, DetailedFungibleAssetOnChain } from '@onomy/hub';
import { useDetailedBalance } from '@onomy/react-hub';
import { useOnomyApp } from '../../wallet/providers/OnomyApp';
import { BLANK_ONEX_HISTORY_FRAME, OnexHistoryFrame } from './OnexHistoryFrames';
import { useOnexDetailedLastExecutionPrice } from '../hooks';

export type DayTradeFrame = OnexHistoryFrame & {
  loadingStatus: AsyncStatus;
  priceDiff: number;
  priceChangeRatio: number;
  volumeDiffRatio: number;
  lastPricePerBase: DetailedFungibleAssetBalance;
  lastPricePerBaseStatus: AsyncStatus;
  volumeAmount: DetailedFungibleAssetBalance;
  volumeAmountStatus: AsyncStatus;
  volumeDiffAmount: DetailedFungibleAssetBalance;
  volumeDiffAmountStatus: AsyncStatus;
};

export function useOnexDayTradeFrame({
  baseAsset,
  quoteAsset,
}: {
  baseAsset: DetailedFungibleAssetOnChain;
  quoteAsset: DetailedFungibleAssetOnChain;
}): [DayTradeFrame, AsyncStatus] {
  const baseDenom = baseAsset.id;
  const quoteDenom = quoteAsset.id;

  const { onexHistoryFrames } = useOnomyApp();
  const [lastPricePerBase, lastPricePerBaseStatus] = useOnexDetailedLastExecutionPrice({
    baseAsset,
    quoteAsset,
  });

  const [[prevFrame = BLANK_ONEX_HISTORY_FRAME, priceFrame = BLANK_ONEX_HISTORY_FRAME], status] =
    useSubscribedValue(
      useCallback(
        (cb: (val: OnexHistoryFrame[]) => void) => {
          if (baseDenom === quoteDenom || !onexHistoryFrames) {
            cb([]);
            return () => {};
          }
          return onexHistoryFrames.subscribe(
            [
              {
                frameType: 'Day',
                skipped: 0,
                baseDenom,
                quoteDenom,
                first: 2,
              },
            ],
            cb
          );
        },
        [onexHistoryFrames, baseDenom, quoteDenom]
      ),
      [BLANK_ONEX_HISTORY_FRAME, BLANK_ONEX_HISTORY_FRAME]
    );

  const startPrice = parseFloat(priceFrame.startPrice);
  const endPrice = parseFloat(priceFrame.endPrice);
  const priceDiff = endPrice - startPrice;
  const priceChangeRatio = priceDiff / startPrice;

  const volumeDiff = new BigNumber(priceFrame.volume).minus(prevFrame.volume);
  const volumeDiffRatio = volumeDiff.dividedBy(prevFrame.volume).toNumber();

  const [volumeAmount, volumeAmountStatus] = useDetailedBalance(baseAsset, priceFrame.volume);
  const [volumeDiffAmount, volumeDiffAmountStatus] = useDetailedBalance(
    baseAsset,
    volumeDiff.toFixed(0)
  );

  const loadingStatus = useAsyncStatuses([
    lastPricePerBaseStatus,
    status,
    volumeAmountStatus,
    volumeDiffAmountStatus,
  ]);

  return [
    {
      ...priceFrame,
      loadingStatus,
      lastPricePerBase,
      lastPricePerBaseStatus,
      priceDiff,
      priceChangeRatio,
      volumeDiffRatio,
      volumeAmount,
      volumeAmountStatus,
      volumeDiffAmount,
      volumeDiffAmountStatus,
    },
    status,
  ];
}

==> react-app-logic-17.1.0.tgz: package/src/exchange/TheGraph/useOnexDayTradeFrame.ts <==
/* eslint-disable class-methods-use-this */
import BigNumber from 'bignumber.js';
import { useCallback } from 'react';
import { AsyncStatus, useAsyncStatuses, useSubscribedValue } from '@onomy/react-utils';
import { DetailedFungibleAssetBalance, DetailedFungibleAssetOnChain } from '@onomy/hub';
import { useDetailedBalance } from '@onomy/react-hub';
import { useOnomyApp } from '../../wallet/providers/OnomyApp';
import { BLANK_ONEX_HISTORY_FRAME, OnexHistoryFrame } from './OnexHistoryFrames';
import { useOnexDetailedLastExecutionPrice } from '../hooks';

export type DayTradeFrame = OnexHistoryFrame & {
  loadingStatus: AsyncStatus;
  priceDiff: number;
  priceChangeRatio: number;
  volumeDiffRatio: number;
  lastPricePerBase: DetailedFungibleAssetBalance;
  lastPricePerBaseStatus: AsyncStatus;
  volumeAmount: DetailedFungibleAssetBalance;
  volumeAmountStatus: AsyncStatus;
  volumeDiffAmount: DetailedFungibleAssetBalance;
  volumeDiffAmountStatus: AsyncStatus;
};

export function useOnexDayTradeFrame({
  baseAsset,
  quoteAsset,
}: {
  baseAsset: DetailedFungibleAssetOnChain | null;
  quoteAsset: DetailedFungibleAssetOnChain | null;
}): [DayTradeFrame, AsyncStatus] {
  const baseDenom = baseAsset?.id ?? '';
  const quoteDenom = quoteAsset?.id ?? '';

  const { onexHistoryFrames } = useOnomyApp();
  const [lastPricePerBase, lastPricePerBaseStatus] = useOnexDetailedLastExecutionPrice({
    baseAsset,
    quoteAsset,
  });

  const [[prevFrame = BLANK_ONEX_HISTORY_FRAME, priceFrame = BLANK_ONEX_HISTORY_FRAME], status] =
    useSubscribedValue(
      useCallback(
        (cb: (val: OnexHistoryFrame[]) => void) => {
          if (baseDenom === quoteDenom || !onexHistoryFrames || !baseDenom || !quoteDenom) {
            cb([]);
            return () => {};
          }
          return onexHistoryFrames.subscribe(
            [
              {
                frameType: 'Day',
                skipped: 0,
                baseDenom,
                quoteDenom,
                first: 2,
              },
            ],
            cb
          );
        },
        [onexHistoryFrames, baseDenom, quoteDenom]
      ),
      [BLANK_ONEX_HISTORY_FRAME, BLANK_ONEX_HISTORY_FRAME]
    );

  const startPrice = parseFloat(priceFrame.startPrice);
  const endPrice = parseFloat(priceFrame.endPrice);
  const priceDiff = endPrice - startPrice;
  const priceChangeRatio = priceDiff / startPrice;

  const volumeDiff = new BigNumber(priceFrame.volume).minus(prevFrame.volume);
  const volumeDiffRatio = volumeDiff.dividedBy(prevFrame.volume).toNumber();

  const [volumeAmount, volumeAmountStatus] = useDetailedBalance(baseAsset, priceFrame.volume);
  const [volumeDiffAmount, volumeDiffAmountStatus] = useDetailedBalance(
    baseAsset,
    volumeDiff.toFixed(0)
  );

  const loadingStatus = useAsyncStatuses([
    lastPricePerBaseStatus,
    status,
    volumeAmountStatus,
    volumeDiffAmountStatus,
  ]);

  return [
    {
      ...priceFrame,
      loadingStatus,
      lastPricePerBase,
      lastPricePerBaseStatus,
      priceDiff,
      priceChangeRatio,
      volumeDiffRatio,
      volumeAmount,
      volumeAmountStatus,
      volumeDiffAmount,
      volumeDiffAmountStatus,
    },
    status,
  ];
}
